From f52b2eddfa12bc14085a718edf8144b115278127 Mon Sep 17 00:00:00 2001
From: basos g<noxelia 4t gmail c0m>
Date: Fri, 12 Dec 2008 17:12:17 +0200
Subject: [PATCH] Added vlc_get_libvlc_object to libvlccore

It is intented to expose the libvlc_int_t (the main vlc object)
to enable extented vlc hacking.. E.g. when you need to make something
with configuration or modules that it is not provided by the PUBLIC API,
you expose the libvlc_int_t as an vlc_object_t and act upon it with
the internal (libvlccore) API...
---
 include/vlc_main.h |   17 +++++++++++++++++
 src/libvlc.c       |    7 +++++++
 src/libvlccore.sym |    1 +
 3 files changed, 25 insertions(+), 0 deletions(-)

diff --git a/include/vlc_main.h b/include/vlc_main.h
index 119b177..77004c6 100644
--- a/include/vlc_main.h
+++ b/include/vlc_main.h
@@ -49,3 +49,20 @@ struct libvlc_int_t
     } *p_hotkeys;
 };
 
+/** This structure the libvlc instance as represented to the PUBLIC API
+  *    It is a redeclaration from include/vlc/libvlc_structures.h to avoid
+  *    including the hole header here
+  */
+struct libvlc_instance_t;
+
+/**
+ * Return the libvlc internal object, the main object that all other depend on.
+ *  This function should be handfull *only* when hacking. E.g. you need to
+ *  expose some functionality that is not provided by the libvlc API by using functions
+ *  from libvlccore that act upon struct libvlc_object_t.
+ *   Remember to release the object with vlc_object_release( obj* )
+ *
+ * \param p_instance the libvlc instance
+ */
+VLC_EXPORT( vlc_object_t* , vlc_get_libvlc_object, ( struct libvlc_instance_t* p_instance ) );
+
diff --git a/src/libvlc.c b/src/libvlc.c
index f085509..5840b69 100644
--- a/src/libvlc.c
+++ b/src/libvlc.c
@@ -1196,6 +1196,13 @@ int libvlc_InternalAddIntf( libvlc_int_t *p_libvlc, char const *psz_module )
     return VLC_SUCCESS;
 };
 
+/* export internal libvlc_instance for hacking (@libvlccore) */
+vlc_object_t* vlc_get_libvlc_object( libvlc_instance_t* p_instance )
+{
+    vlc_object_hold( p_instance->p_libvlc_int ) ;
+    return (vlc_object_t*) p_instance->p_libvlc_int ;
+}
+
 #if defined( ENABLE_NLS ) && (defined (__APPLE__) || defined (WIN32)) && \
     ( defined( HAVE_GETTEXT ) || defined( HAVE_INCLUDED_GETTEXT ) )
 /*****************************************************************************
diff --git a/src/libvlccore.sym b/src/libvlccore.sym
index 37fe6e3..1f272b9 100644
--- a/src/libvlccore.sym
+++ b/src/libvlccore.sym
@@ -492,6 +492,7 @@ __vlc_object_set_destructor
 __vlc_object_signal_unlocked
 __vlc_object_unlock
 __vlc_object_wait
+vlc_get_libvlc_object
 vlc_poll
 vlc_rand_bytes
 vlc_recvmsg
-- 
1.5.6.5

